@@ -21,9 +21,7 @@
 #ifndef SSHAGENT_MAIN_H
 #define SSHAGENT_MAIN_H
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
+#include <freerdp/config.h>
 
 #include <winpr/stream.h>
 
@@ -35,8 +33,10 @@
 #ifdef WITH_DEBUG_SSHAGENT
 #define DEBUG_SSHAGENT(...) WLog_DBG(DVC_TAG, __VA_ARGS__)
 #else
-#define DEBUG_SSHAGENT(...) do { } while (0)
+#define DEBUG_SSHAGENT(...) \
+	do                      \
+	{                       \
+	} while (0)
 #endif
 
 #endif /* SSHAGENT_MAIN_H */
-
