@@ -23,7 +23,6 @@
 #include <freerdp/freerdp.h>
 #include <freerdp/client/channels.h>
 #include <freerdp/client/rdpei.h>
-#include <freerdp/client/tsmf.h>
 #include <freerdp/client/rail.h>
 #include <freerdp/client/cliprdr.h>
 #include <freerdp/client/rdpgfx.h>
@@ -32,7 +31,7 @@
 #include <freerdp/client/geometry.h>
 #include <freerdp/client/video.h>
 
-void xf_OnChannelConnectedEventHandler(void* context, ChannelConnectedEventArgs* e);
-void xf_OnChannelDisconnectedEventHandler(void* context, ChannelDisconnectedEventArgs* e);
+void xf_OnChannelConnectedEventHandler(void* context, const ChannelConnectedEventArgs* e);
+void xf_OnChannelDisconnectedEventHandler(void* context, const ChannelDisconnectedEventArgs* e);
 
 #endif /* FREERDP_CLIENT_X11_CHANNELS_H */
